@@ -2,7 +2,7 @@ from oceanbolt.sdk.client import APIClient
 from oceanbolt.sdk.data import Ports, Countries, Commodities, Segments, Regions, Zones
 from oceanbolt.sdk.data import TradeFlows, TradeFlowTimeseries
 from oceanbolt.sdk.data import PortCalls, PortCallTimeseries
-from oceanbolt.sdk.data import TonnageZoneTimeseries, FleetSpeedTimeseries
+from oceanbolt.sdk.data import TonnageZoneTimeseries, FleetSpeedTimeseries, ChineseWatersTimeseries
 from oceanbolt.sdk.data import CongestionVessels, CongestionTimeseries
 
 __client__ = APIClient()
@@ -67,11 +67,16 @@ def test_tonnage_count():
     assert len(df) > 0
 
 
-def test_fleet_soeed():
+def test_fleet_speed():
     df = FleetSpeedTimeseries(__client__).get(segment=["handysize"], start_date="2021-01-01")
     assert len(df) > 0
 
 
+def test_chinese_waters():
+    df = ChineseWatersTimeseries(__client__).get(segment=["handysize"], start_date="2021-01-01")
+    assert len(df) > 0
+
+
 def test_trade_flows():
     df = TradeFlows(__client__).get(load_country_code=["cn"], start_date="2021-01-01")
     assert len(df) > 0
